@@ -1,7 +1,8 @@
-# Copyright (C) 2010 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
+# Copyright (C) 2011 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
 # This program is free software; you can redistribute and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation. This program is distributed WITHOUT ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program (see gpl-2.0.txt). If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or visit the Free Software Foundation web page, http://www.fsf.org.
 # Author: Daniel Nuest (daniel.nuest@uni-muenster.de)
 # Project: sos4R - visit the project web page, http://www.nordholmen.net/sos4r
+library("sos4R")
 
 ################################################################################
 # http://ispacevm10.researchstudio.at/sostester/
@@ -144,4 +145,6 @@ summary(ooe)
 # http://spatial-analyst.net/wiki/index.php?title=Export_maps_to_GE
 
 
-cat("Demo finished, try another one!\n")
\ No newline at end of file
+###################################
+# Demo finished, try another one! #
+###################################
\ No newline at end of file
