@@ -1,9 +1,12 @@
-# Copyright (C) 2010 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
+# Copyright (C) 2011 by 52 North Initiative for Geospatial Open Source Software GmbH, Contact: info@52north.org
 # This program is free software; you can redistribute and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation. This program is distributed WITHOUT ANY WARRANTY; even without the implied WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with this program (see gpl-2.0.txt). If not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or visit the Free Software Foundation web page, http://www.fsf.org.
 # Author: Daniel Nuest (daniel.nuest@uni-muenster.de)
 # Project: sos4R - visit the project web page, http://www.nordholmen.net/sos4r
 library("sos4R")
 
+################################################################################
+# WeatherSOS
+#
 # establish a connection to a SOS instance with default settings
 weathersos <- SOS(url = "http://v-swe.uni-muenster.de:8080/WeatherSOS/sos")
 summary(weathersos)
@@ -22,7 +25,8 @@ title(main = paste("Offerings by '", sosTitle(weathersos), "'", sep = ""),
 
 # get the latest observation (not standard conform!)
 off <- sosOfferings(weathersos)[["ATMOSPHERIC_TEMPERATURE"]]
-obs <- getObservation(sos = weathersos, offering = off, latest = TRUE)
+obs <- getObservation(sos = weathersos, offering = off, #verbose = TRUE,
+		latest = TRUE)
 
 # show the result for latest observation
 sosResult(obs)
@@ -30,11 +34,13 @@ sosResult(obs)
 ############################################
 # Request two procedures, then create a plot
 # Attention: plots ignore the fact that the times do NOT perfectly match!
-obs <- getObservation(sos = weathersos, offering = off,
-		procedure = sosProcedures(off), inspect = TRUE,
+obs <- getObservation(sos = weathersos,
+		offering = off,
+		procedure = sosProcedures(off),
+		inspect = TRUE,
 		eventTime = sosCreateTime(weathersos,
 				time = "2009-08-10 12:00::2009-08-20 12:00"))
-str(obs[[1]])
+str(obs[[1]], max.level = 3)
 str(obs[[2]]@result)
 summary(obs)
 
@@ -95,7 +101,7 @@ lines(data$Time, x$fitted, col = 'red', lwd=3)
 # DescribeSensor Operation
 procs <- unique(unlist(sosProcedures(weathersos)))
 
-describeSensor(weathersos, procs[[1]])
+describeSensor(weathersos, procs[[1]]) #, verbose = TRUE)
 
 procs.descr <- lapply(X = procs, FUN = describeSensor, # verbose = TRUE,
 		sos = weathersos)
@@ -134,4 +140,6 @@ text(sosCoordinates(procs.descr)[c("x", "y")], labels = sosId(procs.descr),
 		pos = 4)
 title(main = paste("Sensors of", sosTitle(weathersos)))
 
-cat("Demo finished, try another one!\n")
\ No newline at end of file
+###################################
+# Demo finished, try another one! #
+###################################
\ No newline at end of file
